# frozen_string_literal: true

module Hermes
  module Api
    module Dmo
      # checker Api::Dmo::HermesController avant d'ajouter des methodes
      class LessorsController < Hermes::Api::Dmo::ApplicationController
        set_instance_for :objectives

        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $gt
          $gte
          $lt
          $lte
          $eq
          $regex
          $all
        ]

        ACCEPTABLE_PARAMS = %w[
          ids
          als_id
          created_at
          updated_at
          title
          siret
          siren
          is_root
          root_id
          api_id
          rpls_id
          affiliate
          housing_offer_ids
          lessor_objective_ids
          group_id
          supervisor_group_id
          manager_group_id
        ]

        REGEX_PARAMS = %w[
          title
          siret
          siren
        ]

        OBJECTIVES_ACCEPTABLE_PARAMS = %w[
          created_at
          updated_at
          activation_date
          department
          district
          threshold_type
          priority_public
          never_inhabited
          target_by_typologies
          realized_by_typologies
          present_typologies
        ]

        OBJECTIVES_REGEX_PARAMS = %w[
          district
        ]

        MUTATE_PARAMS = %i[
          title
          siret
          siren
          is_root
          root_id
          api_id
          rpls_id
          affiliate
          housing_offer_ids
          lessor_objective_ids
        ]
        mutate_params_only *MUTATE_PARAMS

        def index
          acceptable_params *ACCEPTABLE_PARAMS
          regex_params *REGEX_PARAMS
          valid_operators *VALID_OPERATORS
          super
        end

        def objective_handle_params
          acceptable_params *OBJECTIVES_ACCEPTABLE_PARAMS
          regex_params *OBJECTIVES_REGEX_PARAMS
          valid_operators *VALID_OPERATORS
        end

        def paginate_objectives(objectives)
          objective_handle_params
          objectives = objectives.where(build_query(Hermes::LessorObjective))
                      .order(order_params)
          Rails.logger.debug "TEST #{objectives.selector}"
          paginate(
            objectives,
            each_serializer: Hermes::LessorObjectiveSerializer
          )
        end

        def all_objectives
          objectives = @instance.lessor_objectives
          paginate_objectives(objectives)
        end

        def active_objectives
          objectives = @instance.lessor_objectives.actives
          paginate_objectives(objectives)
        end
      end
    end
  end
end
