module Hermes
  class HousingRequestInitializer
    include Hermes::Concerns::CommonFieldsConcern
    RANDOM_LIST_CHAR = '012345678901234567890123456789012345678901234567890123abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'
    
    field :unique_number, type: String
    field :hashed_pin_code, type: String
    field :pin_code_created_at, type: DateTime
    field :email, type: String
    field :xml_res, type: String

    def hash_string(str)
      Digest::SHA2.new(512).hexdigest(str)
    end

    def format_mail_body(pin_code)
      "Bonjour,

vous recevez ce mél suite à une tentative de récupération de votre demande sur la base de son numéro unique.
Afin de confirmer cette récupération pour que votre demande soit dupliquée sur notre site MaSolutionLogement, veuillez saisir le clé de sécurité dans la zone prévue à cet effet.

Clé de sécurité : #{pin_code}

Attention, cette clé de sécurité est valable une heure. Passé ce délai il sera nécessaire de recommencer votre démarche.
Si vous n'êtes pas à l'origine de cette demande, veuillez ne pas prendre en considération ce mél.

Cordialement

Toute l'équipe Ma Solution Logement

ps : ceci est un message automatique, il est inutile de répondre à ce mél.
"
    end

    def call_sne
    #todo: faire toute la requete à partir du numéro unique jusqu'a récuperer
      
      return {email: "recette.hermes@actionlogement.fr", err: nil}
    end
    
    def send_pin_code_on_mail
      sne_response = call_sne
      return sne_response[:err] if sne_response[:err]
      return false unless sne_response[:email]
      
      random_list_array = RANDOM_LIST_CHAR.split(//)
      pin_code = ''
      6.times do |i|
        pin_code += random_list_array[(SecureRandom.random_number * random_list_array.length).floor]
      end
      self.hashed_pin_code = hash_string(pin_code)
      self.pin_code_created_at = DateTime.current
      mail = Agent.bulk_mail(
          sne_response[:email],
          'securite@masolutionlogement.fr', #
          'Récupération demande SNE',
          format_mail_body(pin_code)
      )
      return false unless mail.deliver_later
      
      save
      pin_code
    end
    
    def check_pin_code(user_input)
      return false unless hashed_pin_code && pin_code_created_at
      
      hash_string(user_input) == hashed_pin_code &&
          (Time.current - pin_code_created_at) < 1.hours
    end
  end

end